==> estateplat-common-1.2.4-20201112.062002-497-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzShzzdm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/11
 * @description 省级信息共享-民政-社会组织代码
 */
@Table(name = "xxgx_mz_shzzdm")
public class XxgxMzShzzdm {
    @Id
    private String shzzdmid;//社会组织代码id
    private String tyshxydm;//统一社会信用代码
    private String cxfwlxdm;//查询服务类型代码
    private String ywfw;//业务范围
    private String zsdz;//住所地址
    private Integer sfcszz;//是否慈善组织
    private String fzjg;//发证机关
    private String fddbr;//法定代表人
    private String zgdw;//主管单位
    private String shzzmc;//社会组织名称
    private Integer zczj;//注册资金
    private Date fzrq;//发证日期
    private Date zsyxqq;//证书有效期起
    private Date zsyxqz;//证书有效期止
    private String hddy;//活动地域
    private String proid;//项目id

    public String getShzzdmid() {
        return shzzdmid;
    }

    public void setShzzdmid(String shzzdmid) {
        this.shzzdmid = shzzdmid;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public String getCxfwlxdm() {
        return cxfwlxdm;
    }

    public void setCxfwlxdm(String cxfwlxdm) {
        this.cxfwlxdm = cxfwlxdm;
    }

    public String getYwfw() {
        return ywfw;
    }

    public void setYwfw(String ywfw) {
        this.ywfw = ywfw;
    }

    public String getZsdz() {
        return zsdz;
    }

    public void setZsdz(String zsdz) {
        this.zsdz = zsdz;
    }

    public Integer getSfcszz() {
        return sfcszz;
    }

    public void setSfcszz(Integer sfcszz) {
        this.sfcszz = sfcszz;
    }

    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getZgdw() {
        return zgdw;
    }

    public void setZgdw(String zgdw) {
        this.zgdw = zgdw;
    }

    public String getShzzmc() {
        return shzzmc;
    }

    public void setShzzmc(String shzzmc) {
        this.shzzmc = shzzmc;
    }

    public Integer getZczj() {
        return zczj;
    }

    public void setZczj(Integer zczj) {
        this.zczj = zczj;
    }

    public Date getFzrq() {
        return fzrq;
    }

    public void setFzrq(Date fzrq) {
        this.fzrq = fzrq;
    }

    public Date getZsyxqq() {
        return zsyxqq;
    }

    public void setZsyxqq(Date zsyxqq) {
        this.zsyxqq = zsyxqq;
    }

    public Date getZsyxqz() {
        return zsyxqz;
    }

    public void setZsyxqz(Date zsyxqz) {
        this.zsyxqz = zsyxqz;
    }

    public String getHddy() {
        return hddy;
    }

    public void setHddy(String hddy) {
        this.hddy = hddy;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20201125.072327-548-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzShzzdm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/11
 * @description 省级信息共享-民政-社会组织代码
 */
@Table(name = "xxgx_mz_shzzdm")
public class XxgxMzShzzdm {
    @Id
    private String shzzdmid;//社会组织代码id
    private String tyshxydm;//统一社会信用代码
    private String cxfwlxdm;//查询服务类型代码
    private String ywfw;//业务范围
    private String zsdz;//住所地址
    private Integer sfcszz;//是否慈善组织
    private String fzjg;//发证机关
    private String fddbr;//法定代表人
    private String zgdw;//主管单位
    private String shzzmc;//社会组织名称
    private Double zczj;//注册资金
    private Date fzrq;//发证日期
    private Date zsyxqq;//证书有效期起
    private Date zsyxqz;//证书有效期止
    private String hddy;//活动地域
    private String proid;//项目id

    public String getShzzdmid() {
        return shzzdmid;
    }

    public void setShzzdmid(String shzzdmid) {
        this.shzzdmid = shzzdmid;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public String getCxfwlxdm() {
        return cxfwlxdm;
    }

    public void setCxfwlxdm(String cxfwlxdm) {
        this.cxfwlxdm = cxfwlxdm;
    }

    public String getYwfw() {
        return ywfw;
    }

    public void setYwfw(String ywfw) {
        this.ywfw = ywfw;
    }

    public String getZsdz() {
        return zsdz;
    }

    public void setZsdz(String zsdz) {
        this.zsdz = zsdz;
    }

    public Integer getSfcszz() {
        return sfcszz;
    }

    public void setSfcszz(Integer sfcszz) {
        this.sfcszz = sfcszz;
    }

    public String getFzjg() {
        return fzjg;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getZgdw() {
        return zgdw;
    }

    public void setZgdw(String zgdw) {
        this.zgdw = zgdw;
    }

    public String getShzzmc() {
        return shzzmc;
    }

    public void setShzzmc(String shzzmc) {
        this.shzzmc = shzzmc;
    }

    public Double getZczj() {
        return zczj;
    }

    public void setZczj(Double zczj) {
        this.zczj = zczj;
    }

    public Date getFzrq() {
        return fzrq;
    }

    public void setFzrq(Date fzrq) {
        this.fzrq = fzrq;
    }

    public Date getZsyxqq() {
        return zsyxqq;
    }

    public void setZsyxqq(Date zsyxqq) {
        this.zsyxqq = zsyxqq;
    }

    public Date getZsyxqz() {
        return zsyxqz;
    }

    public void setZsyxqz(Date zsyxqz) {
        this.zsyxqz = zsyxqz;
    }

    public String getHddy() {
        return hddy;
    }

    public void setHddy(String hddy) {
        this.hddy = hddy;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
